@@ -239,7 +239,11 @@ def data_aug(aug_file):
 
     # 生成新的trainval.txt
     voc_txt_dir = os.path.join(top_dir, "ImageSets", "Main")
-    os.makedirs(voc_txt_dir, exist_ok=True)
+    if os.path.exists(voc_txt_dir):
+        for voc_txt in os.listdir(voc_txt_dir):
+            os.remove(os.path.join(voc_txt_dir, voc_txt))
+    else:
+        os.makedirs(voc_txt_dir, exist_ok=True)
     txt_path = os.path.join(voc_txt_dir, "trainval.txt")
     xml_names = []
     for root, _, files in os.walk(XML_DIR):
