@@ -153,7 +153,7 @@ def get_labels(label_file):
         txt_list = fr.readlines()
         for index, item in enumerate(txt_list):
             item_list = item.split(" ")
-            labels.append(item_list[0])
+            labels.append(item_list[0].replace("\n", ""))
 
     return labels
 
